==> haskell-hi-file-parser-0.1.8.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.8.0
visibility:           public
id:                   hi-file-parser-0.1.8.0-B45qT8gFllE5Zz4T782omQ
key:                  hi-file-parser-0.1.8.0-B45qT8gFllE5Zz4T782omQ
license:              BSD-3-Clause
copyright:            Copyright 2015-2025, Stack contributors
maintainer:
    Michael Snoyman <michael@snoyman.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Hussein Ait-Lahcen <hussein.aitlahcen@gmail.com>
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s *.hi files
description:
    A parser for GHC'\''s *.hi files. Extracts information about dependencies and
    usage of files.

category:             Development
abi:                  11e0c30049f1bffea57d6af015de8272
exposed:              True
exposed-modules:      HiFileParser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.8.0-B45qT8gFllE5Zz4T782omQ
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.2.2
    rio-0.1.22.0-54W0I1q00EUHTWXR7QhDxE text-2.0.2
    vector-0.13.2.0-BxFNQQxQb2S1T9ycXEZ0Cs

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.8.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.8.0
visibility:           public
id:                   hi-file-parser-0.1.8.0-1NnQUaKsGfeLRMmt9Iv3Vr
key:                  hi-file-parser-0.1.8.0-1NnQUaKsGfeLRMmt9Iv3Vr
license:              BSD-3-Clause
copyright:            Copyright 2015-2025, Stack contributors
maintainer:
    Michael Snoyman <michael@snoyman.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Hussein Ait-Lahcen <hussein.aitlahcen@gmail.com>
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s *.hi files
description:
    A parser for GHC'\''s *.hi files. Extracts information about dependencies and
    usage of files.

category:             Development
abi:                  040a94bae5c3e72cb469c3bcd4d0dd35
exposed:              True
exposed-modules:      HiFileParser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.8.0-1NnQUaKsGfeLRMmt9Iv3Vr
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.2.2
    rio-0.1.22.0-BzQdBogcbjZJssEGmBibyZ text-2.0.2
    vector-0.13.2.0-Fx80VLFrFKz3Sy2krWU8Ue

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
